@@ -3,9 +3,9 @@ use strict;
 use warnings;
 
 package Mxpress::PDF {
-	our $VERSION = '0.07';
+	our $VERSION = '0.08';
 	use Zydeco (
-		version	=> '0.07',
+		version	=> '0.08',
 		authority => 'cpan:LNATION',
 	);
 	use Colouring::In;
@@ -210,7 +210,7 @@ package Mxpress::PDF {
 				$self->current->set_position(
 					($self->x > 100 ? ($self->x - $p) : ($self->x + $p)),
 					($self->y > 100 ? ($self->y - $p) : ($self->y + $p)),
-					($self->w - ($p*2)),
+					($self->w - $p),
 					$self->h
 				);
 			}
@@ -897,7 +897,7 @@ Mxpress::PDF - PDF
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
